import QtQuick 2.0
import Ubuntu.Components 0.1

Item {
    id: dot

    property int index
    property int totalElements: parent.totalDots
    property int animLength: index * totalElements * 15

    property double infoGraphicsX: parent.x + parent.horizontalCenter
    property double infoGraphicsY: parent.y + parent.verticalCenter
    property double infoGraphicsHalfWidth: parent.width / 2
    property double infoGraphicsHalfHeight: parent.height / 2

    state: "pointer"
    visible: false

    function triggerStartAnimation() {
        unlockAnim.start()
    }

    SequentialAnimation {
        id: unlockAnim

        PauseAnimation { duration: animLength }
        PropertyAction {
            target: dot
            property: "visible"
            value: "true"
        }
        PropertyAnimation {
            target: dot
            property: "state"
            to: "unfilled"
        }
    }

Image {
    id: sprite

    property real halfWidth: width / 2
    property real halfHeight: height / 2

    property real slice: (2 * Math.PI / totalElements) * index;
    property real radius: infoGraphicsHalfWidth - halfWidth

    x: infoGraphicsHalfWidth - halfWidth + radius * Math.sin(slice)
    y: infoGraphicsHalfHeight - halfHeight + radius * -Math.cos(slice)

    transform: Rotation {
        id: rotationTransform

        origin.x: sprite.halfWidth
        origin.y: sprite.halfHeight

        angle: Math.atan2(dot.infoGraphicsY+dot.infoGraphicsHalfHeight-(sprite.y+sprite.halfHeight), dot.infoGraphicsX+
                          dot.infoGraphicsHalfWidth-(sprite.x+sprite.halfWidth)) * 180 / Math.PI - 90
    }

    //Circle animations:
    /*transform: Scale {
        id: scaleTransform
        property real scale: 1
        xScale: scale
        yScale: scale
        origin.x: sprite.halfWidth
        origin.y: sprite.halfHeight
    }

    SequentialAnimation {
        id: startAnimation
        loops: 1
        PauseAnimation { duration: dot.index * 100 }
        PropertyAnimation {
            target: scaleTransform
            properties: "scale"
            from: 0.5
            to: 1.5
            duration: 250
        }
        PropertyAnimation {
            target: scaleTransform
            properties: "scale"
            from: 1.2
            to: 1.0
            duration: 250
        }
    }*/
}

states: [
        State {
            name: "unfilled"
            PropertyChanges { target: sprite; source: "graphics/dot_empty@30.png" }
        },

        State {
            name: "filled"
            PropertyChanges { target: sprite; source: "graphics/dot_filled@30.png" }
        },

        State {
            name: "pointer"
            PropertyChanges { target: sprite; source: "graphics/dot_pointer@30.png" }
    }
]
}
